// Dependencies
var Promise = require('bluebird');
var moment  = require('moment');
var request = Promise.promisifyAll(require('request'));
var geocode = Promise.promisifyAll(require('notebook')('capicue/geocode/2.0.0'));

// API endpoints
var issNowUrl  = 'http://api.open-notify.org/iss-now.json';
var issPassUrl = 'http://api.open-notify.org/iss-pass.json';
var astrosUrl  = 'http://api.open-notify.org/astros.json'; 0;;

function currentPosition() {
    return request.getAsync(issNowUrl).then(function(body) {
        return JSON.parse(body[1]).iss_position;
    });
}

await currentPosition();;

// Change to use your own location
var myLocation = "San Francisco, CA";

function nextPass(location) {
    return geocode.lookupAsync(location).then(function(coordinates) {
        var options = {lat: coordinates.lat, lon: coordinates.lng};
        return request.getAsync({url: issPassUrl, qs: options});
    }).then(function(passResult) {
        var timestamp = JSON.parse(passResult[1]).response[0].risetime;
        return moment.unix(timestamp).fromNow();
    });
}

await nextPass(myLocation);;

function numberInSpace() {
    return request.getAsync(astrosUrl).then(function(response) {
        return JSON.parse(response[1]).number;
    });
}

await numberInSpace();;

function peopleInSpace() {
    return request.getAsync(astrosUrl).then(function(response) {
        return JSON.parse(response[1]).people;
    });
}

var people = await peopleInSpace();
people.map(function(person) {
    return person.name + " (" + person.craft + ")";
});;
module.exports = {
    currentPosition: currentPosition,
    nextPass: nextPass,
    numberInSpace: numberInSpace,
    peopleInSpace: peopleInSpace
};;